@@ -2,8 +2,6 @@
 Keyring implementation support
 """
 
-from __future__ import absolute_import
-
 import abc
 import logging
 import operator
@@ -12,20 +10,23 @@ import entrypoints
 
 from . import credentials, errors, util
 from .util import properties
-from .py27compat import add_metaclass, filter
 
 __metaclass__ = type
 
 log = logging.getLogger(__name__)
 
 
+by_priority = operator.attrgetter('priority')
+_limit = None
+
+
 class KeyringBackendMeta(abc.ABCMeta):
     """
     A metaclass that's both an ABCMeta and a type that keeps a registry of
     all (non-abstract) types.
     """
     def __init__(cls, name, bases, dict):
-        super(KeyringBackendMeta, cls).__init__(name, bases, dict)
+        super().__init__(name, bases, dict)
         if not hasattr(cls, '_classes'):
             cls._classes = set()
         classes = cls._classes
@@ -33,8 +34,7 @@ class KeyringBackendMeta(abc.ABCMeta):
             classes.add(cls)
 
 
-@add_metaclass(KeyringBackendMeta)
-class KeyringBackend:
+class KeyringBackend(metaclass=KeyringBackendMeta):
     """The abstract base class of the keyring, every backend must implement
     this interface.
     """
@@ -84,9 +84,9 @@ class KeyringBackend:
 
     def __str__(self):
         keyring_class = type(self)
-        return ("%s.%s (priority: %g)" % (keyring_class.__module__,
-                                          keyring_class.__name__,
-                                          keyring_class.priority))
+        return ("{}.{} (priority: {:g})".format(keyring_class.__module__,
+                                                keyring_class.__name__,
+                                                keyring_class.priority))
 
     @abc.abstractmethod
     def get_password(self, service, username):
