@@ -1,8 +1,5 @@
 import logging
 
-import sys
-import os
-
 from ..util import properties
 from ..backend import KeyringBackend
 from ..errors import (InitError, PasswordDeleteError,
@@ -22,7 +19,7 @@ log = logging.getLogger(__name__)
 
 class Keyring(KeyringBackend):
     """Secret Service Keyring"""
-    appid = os.path.basename(sys.argv[0]) or 'Python keyring library'
+    appid = 'Python keyring library'
 
     @properties.ClassProperty
     @classmethod
@@ -83,7 +80,7 @@ class Keyring(KeyringBackend):
             "service": service,
             "username": username
         }
-        label = "Password for '%s' on '%s'" % (username, service)
+        label = "Password for '{}' on '{}'".format(username, service)
         collection.create_item(label, attributes, password, replace=True)
 
     def delete_password(self, service, username):
