@@ -1,35 +1,27 @@
-from __future__ import unicode_literals
-
 import functools
 
-from ..py27compat import text_type
 from ..util import properties
 from ..backend import KeyringBackend
+from ..credentials import SimpleCredential
 from ..errors import PasswordDeleteError, ExceptionRaisedContext
 
-try:
-    # prefer pywin32-ctypes
-    from win32ctypes import pywintypes
-    from win32ctypes import win32cred
-    # force demand import to raise ImportError
-    win32cred.__name__
-except ImportError:
-    # fallback to pywin32
+
+with ExceptionRaisedContext() as missing_deps:
     try:
+        # prefer pywin32-ctypes
+        from win32ctypes.pywin32 import pywintypes
+        from win32ctypes.pywin32 import win32cred
+        # force demand import to raise ImportError
+        win32cred.__name__
+    except ImportError:
+        # fallback to pywin32
         import pywintypes
         import win32cred
-    except ImportError:
-        pass
-
-def has_pywin32():
-    """
-    Does this environment have pywin32?
-    Should return False even when Mercurial's Demand Import allowed import of
-    win32cred.
-    """
-    with ExceptionRaisedContext() as exc:
+        # force demand import to raise ImportError
         win32cred.__name__
-    return not bool(exc)
+
+
+__metaclass__ = type
 
 
 class WinVaultKeyring(KeyringBackend):
@@ -56,7 +48,7 @@ class WinVaultKeyring(KeyringBackend):
         """
         If available, the preferred backend on Windows.
         """
-        if not has_pywin32():
+        if missing_deps:
             raise RuntimeError("Requires Windows and pywin32")
         return 5
 
@@ -83,7 +75,7 @@ class WinVaultKeyring(KeyringBackend):
             )
         except pywintypes.error as e:
             e = OldPywinError.wrap(e)
-            if e.winerror == 1168 and e.funcname == 'CredRead': # not found
+            if e.winerror == 1168 and e.funcname == 'CredRead':  # not found
                 return None
             raise
         return res
@@ -95,8 +87,8 @@ class WinVaultKeyring(KeyringBackend):
             existing_username = existing_pw['UserName']
             target = self._compound_name(existing_username, service)
             self._set_password(target, existing_username,
-                existing_pw['CredentialBlob'].decode('utf-16'))
-        self._set_password(service, username, text_type(password))
+                               existing_pw['CredentialBlob'].decode('utf-16'))
+        self._set_password(service, username, str(password))
 
     def _set_password(self, target, username, password):
         credential = dict(Type=win32cred.CRED_TYPE_GENERIC,
@@ -119,17 +111,39 @@ class WinVaultKeyring(KeyringBackend):
             raise PasswordDeleteError(service)
 
     def _delete_password(self, target):
-        win32cred.CredDelete(
-            Type=win32cred.CRED_TYPE_GENERIC,
-            TargetName=target,
+        try:
+            win32cred.CredDelete(
+                Type=win32cred.CRED_TYPE_GENERIC,
+                TargetName=target,
+            )
+        except pywintypes.error as e:
+            e = OldPywinError.wrap(e)
+            if e.winerror == 1168 and e.funcname == 'CredDelete':  # not found
+                return
+            raise
+
+    def get_credential(self, service, username):
+        res = None
+        # get the credentials associated with the provided username
+        if username:
+            res = self._get_password(self._compound_name(username, service))
+        # get any first password under the service name
+        if not res:
+            res = self._get_password(service)
+            if not res:
+                return None
+        return SimpleCredential(
+            res['UserName'],
+            res['CredentialBlob'].decode('utf-16'),
         )
 
 
-class OldPywinError(object):
+class OldPywinError:
     """
     A compatibility wrapper for old PyWin32 errors, such as reported in
     https://bitbucket.org/kang/python-keyring-lib/issue/140/
     """
+
     def __init__(self, orig):
         self.orig = orig
 
