@@ -1,25 +1,14 @@
-from __future__ import print_function
-
 import sys
 import unittest
 
+import pytest
+
 import keyring.backends.Windows
 from ..test_backend import BackendBasicTests
 
-def is_winvault_supported():
-    try:
-        __import__('win32cred')
-        has_pywin32 = True
-    except ImportError:
-        has_pywin32 = False
-    return (
-        sys.platform in ['win32'] and sys.getwindowsversion().major >= 6
-        and has_pywin32
-    )
 
-
-@unittest.skipUnless(is_winvault_supported(),
-                     "Need WinVault")
+@unittest.skipUnless(keyring.backends.Windows.WinVaultKeyring.viable,
+                     "Needs Windows")
 class WinVaultKeyringTestCase(BackendBasicTests, unittest.TestCase):
     def tearDown(self):
         # clean up any credentials created
@@ -31,3 +20,11 @@ class WinVaultKeyringTestCase(BackendBasicTests, unittest.TestCase):
 
     def init_keyring(self):
         return keyring.backends.Windows.WinVaultKeyring()
+
+
+@pytest.mark.skipif('sys.platform != "win32"')
+def test_winvault_always_viable():
+    """
+    The WinVault backend should always be viable on Windows.
+    """
+    assert keyring.backends.Windows.WinVaultKeyring.viable
