@@ -4,8 +4,6 @@
 Common test functionality for backends.
 """
 
-from __future__ import unicode_literals
-
 import string
 
 import pytest
@@ -13,6 +11,8 @@ import pytest
 from .util import random_string
 from keyring import errors
 
+__metaclass__ = type
+
 # unicode only characters
 # Sourced from The Quick Brown Fox... Pangrams
 # http://www.columbia.edu/~fdc/utf8/
@@ -31,7 +31,7 @@ def is_ascii_printable(s):
     return all(32 <= ord(c) < 127 for c in s)
 
 
-class BackendBasicTests(object):
+class BackendBasicTests:
     """Test for the keyring's basic functions. password_set and password_get
     """
 
@@ -111,8 +111,8 @@ class BackendBasicTests(object):
         self.check_set_get(service, username, password)
 
     def test_unicode_and_ascii_chars(self):
-        source = (random_string(10, UNICODE_CHARS) + random_string(10) +
-                  random_string(10, self.DIFFICULT_CHARS))
+        source = (random_string(10, UNICODE_CHARS) + random_string(10)
+                  + random_string(10, self.DIFFICULT_CHARS))
         password = random_string(20, source)
         username = random_string(20, source)
         service = random_string(20, source)
@@ -132,3 +132,25 @@ class BackendBasicTests(object):
         assert keyring.get_password('service1', 'user2') == 'password2'
         self.set_password('service2', 'user3', 'password3')
         assert keyring.get_password('service1', 'user1') == 'password1'
+
+    def test_credential(self):
+        keyring = self.keyring
+
+        cred = keyring.get_credential('service', None)
+        assert cred is None
+
+        self.set_password('service1', 'user1', 'password1')
+        self.set_password('service1', 'user2', 'password2')
+
+        cred = keyring.get_credential('service1', None)
+        assert cred is None or (cred.username, cred.password) in (
+            ('user1', 'password1'),
+            ('user2', 'password2'),
+        )
+
+        cred = keyring.get_credential('service1', 'user2')
+        assert cred is not None
+        assert (cred.username, cred.password) in (
+            ('user1', 'password1'),
+            ('user2', 'password2'),
+        )
